@@ -1,3 +1,4 @@
+import logging
 import re
 from pathlib import Path
 
@@ -20,6 +21,26 @@ def print_files(files):
 def format_files(files):
     formatter = Formatter(files)
     formatter.format_files()
+
+
+def validate(files):
+    format_files(files)
+    logging.basicConfig(filename='verification.log', level=logging.WARN)
+    for file in files:
+        for token in file.tokens:
+            if token.value != token.second_value and token.token_type in (TokenType.comment, TokenType.identifier):
+                logging.warn(f'{file.filename}\t {token.position.row}:{token.position.column}\t -> '
+                             f'expected {token.second_value}, actual {token.value}')
+
+
+def fix(files):
+    format_files(files)
+    logging.basicConfig(filename='fixing.log', level=logging.WARN)
+    for file in files:
+        for token in file.tokens:
+            if token.value != token.second_value and token.token_type in (TokenType.comment, TokenType.identifier):
+                logging.warn(f'{file.filename}\t {token.position.row}:{token.position.column}\t replace '
+                             f'{token.value} -> {token.second_value}')
     print_files(files)
 
 
@@ -98,6 +119,9 @@ class Formatter:
         if Formatter.is_camel_case_first_up(token) or token.token_type != TokenType.identifier:
             return
 
+        if Formatter.is_upper_case(token):
+            token.second_value = token.second_value.lower()
+
         Formatter.replace_underscore_to_uppercase(token)
         token.second_value = Formatter.to_upper(token.second_value, 0)
 
@@ -114,6 +138,9 @@ class Formatter:
         if Formatter.is_camel_case_first_down(token) or token.token_type != TokenType.identifier:
             return
 
+        if Formatter.is_upper_case(token):
+            token.second_value = token.second_value.lower()
+
         Formatter.replace_underscore_to_uppercase(token)
         token.second_value = Formatter.to_lower(token.second_value, 0)
 
@@ -213,7 +240,7 @@ class Formatter:
 
                 elif len(stack) > 2 and stack[-2] == '{' and stack[-1] in ('(', '{'):  # in method
                     if stack[-1] == '(':
-                        after_tokens = (')', ',')
+                        after_tokens = (')', ',', '[')
                     else:
                         after_tokens = (';', '=', ':')
 
@@ -234,7 +261,7 @@ class Formatter:
     @staticmethod
     def fix_documentation_comment(token, indent):
         i = 3
-        while i + 1 < len(token.second_value):
+        while i + 2 < len(token.second_value):
             char = token.second_value[i]
             next_char = token.second_value[i + 1]
             if char == '\n':
@@ -249,8 +276,7 @@ class Formatter:
 
                 token.second_value = token.second_value[:i + 1] + ' ' * indent + ' *' + second_part[local_i:]
             elif char == '*':
-                if next_char not in ('/', ' '):
-                    token.second_value = token.second_value[:i + 1] + ' ' + token.second_value[i + 1:]
+                token.second_value = token.second_value[:i + 1] + ' ' + token.second_value[i + 1:]
 
             i += 1
 
@@ -338,6 +364,9 @@ class Formatter:
 
                 if token.value in (',', ')') and local_previous_token.token_type == TokenType.identifier:
                     local_method_params.append((local_previous_token.value, local_previous_token.second_value))
+                elif token.value == '[' and local_previous_token.token_type == TokenType.identifier and \
+                        file.tokens[i + 2].value == ',':
+                    local_method_params.append((local_previous_token.value, local_previous_token.second_value))
                 elif token.value == '<':
                     count_open = 1
                     while count_open != 0:
@@ -364,7 +393,7 @@ class Formatter:
                 while local_previous_token.value not in (';', '{'):
                     if token.value in (',', ';', '{'):
                         local_method_throws.append((local_previous_token.value, local_previous_token.second_value))
-                    i += 1
+                    i = Formatter.get_next_no_whitespace_token_id(file, i)
                     local_previous_token = token
                     token = file.tokens[i]
 
@@ -411,7 +440,7 @@ class Formatter:
                 _block = _block[:_i] + _block[_i + 1:]
             _block = _block[:_i] + ' ' + _block[_i:]
             next_space = _block.find(' ', _i + 1)
-            return _block, _block[_i + 1:next_space]
+            return _block, _block[_i + 1:next_space].split()[0]
 
         # @param
         i = 0
@@ -422,9 +451,9 @@ class Formatter:
                 blocks.pop(i)
                 i -= 1
 
-                for i in range(len(method_params)):
-                    if method_params[i][1] == name:
-                        method_params.pop(i)
+                for _i in range(len(method_params)):
+                    if method_params[_i][1] == name:
+                        method_params.pop(_i)
                         break
 
             i += 1
@@ -452,9 +481,9 @@ class Formatter:
                 blocks.pop(i)
                 i -= 1
 
-                for i in range(len(method_throws)):
-                    if method_throws[i][1] == name:
-                        method_throws.pop(i)
+                for _i in range(len(method_throws)):
+                    if method_throws[_i][1] == name:
+                        method_throws.pop(_i)
                         break
             i += 1
 
