@@ -1,21 +1,21 @@
 import sys
 
 from .file import File
-from .formatter import format_files, get_files, get_files_rec
+from .formatter import get_files, get_files_rec, fix, validate
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 
 def print_help():
     print(
         """
 ***************** examples *****************
-name --verify -(p|d|f) /..
-name -v -(p|d|f) /..
-name --fix -(p|d|f) /..
-name -f  -(p|d|f) /..
-name --help
-name -h
+AndrikBJavaCCF --verify -(p|d|f) /..
+AndrikBJavaCCF -v -(p|d|f) /..
+AndrikBJavaCCF --fix -(p|d|f) /..
+AndrikBJavaCCF -f  -(p|d|f) /..
+AndrikBJavaCCF --help
+AndrikBJavaCCF -h
 where :
 -p - project
 -d - directory
@@ -53,4 +53,7 @@ def main():
             for i in range(len(files)):
                 files[i] = File(files[i])
 
-            format_files(files)
+            if mode == '-v':
+                validate(files)
+            else:
+                fix(files)
